pub trait DecodeWithVersion: Sized {
// Required method
fn decode_with_version<I>(
extension_version: u8,
input: &mut I,
) -> Result<Self, Error>
where I: Input;
}Expand description
A type that can be decoded from a specific version and a [codec::Input].
Required Methods
Sourcefn decode_with_version<I>(
extension_version: u8,
input: &mut I,
) -> Result<Self, Error>where
I: Input,
fn decode_with_version<I>(
extension_version: u8,
input: &mut I,
) -> Result<Self, Error>where
I: Input,
Decode the type from the given version and input.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.