pub trait IdentifyAccount {
type AccountId;
// Required method
fn into_account(self) -> Self::AccountId;
}Expand description
Some type that is able to be collapsed into an account ID. It is not possible to recreate the original value from the account ID.
Required Associated Types
Required Methods
Sourcefn into_account(self) -> Self::AccountId
fn into_account(self) -> Self::AccountId
Transform into an account.
Implementations on Foreign Types
Sourceimpl IdentifyAccount for CryptoBytes<sp_core::::ecdsa::GenericPublic::{constant#0}, (PublicTag, EcdsaTag)>
impl IdentifyAccount for CryptoBytes<sp_core::::ecdsa::GenericPublic::{constant#0}, (PublicTag, EcdsaTag)>
type AccountId = CryptoBytes<sp_core::::ecdsa::GenericPublic::{constant#0}, (PublicTag, EcdsaTag)>
fn into_account( self, ) -> CryptoBytes<sp_core::::ecdsa::GenericPublic::{constant#0}, (PublicTag, EcdsaTag)>
Sourceimpl IdentifyAccount for CryptoBytes<sp_core::::ed25519::Public::{constant#0}, (PublicTag, Ed25519Tag)>
impl IdentifyAccount for CryptoBytes<sp_core::::ed25519::Public::{constant#0}, (PublicTag, Ed25519Tag)>
type AccountId = CryptoBytes<sp_core::::ed25519::Public::{constant#0}, (PublicTag, Ed25519Tag)>
fn into_account( self, ) -> CryptoBytes<sp_core::::ed25519::Public::{constant#0}, (PublicTag, Ed25519Tag)>
Sourceimpl IdentifyAccount for CryptoBytes<sp_core::::paired_crypto::ecdsa_bls381::Public::{constant#0}, (PublicTag, (PairedCryptoTag, EcdsaBls381Tag))>
Available on crate feature bls-experimental only.
impl IdentifyAccount for CryptoBytes<sp_core::::paired_crypto::ecdsa_bls381::Public::{constant#0}, (PublicTag, (PairedCryptoTag, EcdsaBls381Tag))>
Available on crate feature
bls-experimental only.