referrerpolicy=no-referrer-when-downgrade

PipelineVersion

Trait PipelineVersion 

pub trait PipelineVersion {
    // Required method
    fn version(&self) -> u8;
}
The version for an instance of a versioned transaction extension pipeline.

This trait is part of Pipeline. It is defined independently to allow implementation to rely only on it without bounding the whole trait Pipeline.

(type name is short for versioned (Vers) Pipeline version (Version)).

Required Methods

fn version(&self) -> u8

Return the version for the given versioned transaction extension pipeline.

Implementors

Source

impl PipelineVersion for InvalidVersion

Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z> PipelineVersion for MultiVersion<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z>

Source

impl<ExtensionV0, ExtensionOtherVersions> PipelineVersion for ExtensionVariant<ExtensionV0, ExtensionOtherVersions>
where ExtensionOtherVersions: PipelineVersion,

Source

impl<const VERSION: u8, Extension> PipelineVersion for PipelineAtVers<VERSION, Extension>