pub trait PipelineVersion { // Required method fn version(&self) -> u8; }
The version for an instance of a versioned transaction extension pipeline.
This trait is part of Pipeline. It is defined independently to allow implementation to rely only on it without bounding the whole trait Pipeline.
Pipeline
(type name is short for versioned (Vers) Pipeline version (Version)).
Return the version for the given versioned transaction extension pipeline.